# Forecast_x
> Toolkit with Naive models for time series.

Forecast_x provides different models for fitting applying a naive approach to time series.



## Installation

```sh
pip install -U forecast-x
```


## Release History

* 0.11.1
    * FIX: Missing installation file.
* 0.10
    * The first proper release
* 0.1
    * Work in progress

## Meta

Alejandro De Barros – (https://twitter.com/alejandrodbn) – alejandrodbn@gmail.com

Distributed under the MIT license. See ``LICENSE`` for more information.

[https://github.com/alejandrodbn/forecast](https://github.com/alejandrodbn/)

